Page 142 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 142

Home

    the news media, and ignored by the major religious
    denominations in America. Whenever the U. S. news

    media covered events in Africa, the news has always
    been slanted toward Communist goals and against
    freedom, South Africa being the greatest victim of this

    bias.

    Missionary director Peter Hammond, a native of
    South Africa, related this about the moral conditions in

    You hear so much bad news about South Africa,
    none of which really bears any resemblance to the reality
    in South Africa. One thing people would be surprised to
    learn is what a moral and Christian country South Africa

    or

    really is.

    For example, abortion is illegal in South Africa. You
    may not murder your unborn infants in our country. In
    addition to that, prayer, hymn singing, and Bible reading
    are a compulsory part of everyday school. Hymns are
    sung in the school, Bible reading and prayer at the
    beginning of each school and assembly, and we have
    religious instruction in classes. Pornography is banned in
    South Africa. For example, The Last Temptation of
    Christ was banned in our country. We also have
    compulsory church services in the military.

    Seventy-five percent of the population of South
    Africa attends church every week. But aside from that,
    we have a very high percentage of missionary minded,
    Bible believing, God fearing people who are very zealous
    for their faith.

    For example, South Africa is the largest Bible
    producing country in the world. America produces more

    137

    Babylon's War Against God

    his country: